@@ -55,18 +55,15 @@
 #define DIST_ASSERT_ALIGNED(data) \
     { DIST_ASSERT_ALIGNED_TO((data), ::distributions::default_alignment); }
 
-namespace distributions
-{
+namespace distributions {
 
 // sse instructions require alignment of 16 bytes
 // avx instructions require alignment of 32 bytes
 static const size_t default_alignment = 32;
 
 template<class T, size_t alignment = default_alignment>
-class aligned_allocator
-{
-public:
-
+class aligned_allocator {
+  public:
     typedef T value_type;
     typedef size_t size_type;
     typedef ptrdiff_t difference_type;
@@ -78,29 +75,25 @@ public:
     typedef const T & const_reference;
 
     template <class U>
-    aligned_allocator (const aligned_allocator<U, alignment> &) throw() {}
-    aligned_allocator (const aligned_allocator &) throw() {}
-    aligned_allocator () throw() {}
-    ~aligned_allocator () throw() {}
+    aligned_allocator(const aligned_allocator<U, alignment> &) throw() {}
+    aligned_allocator(const aligned_allocator &) throw() {}
+    aligned_allocator() throw() {}
+    ~aligned_allocator() throw() {}
 
     template<class U>
-    struct rebind
-    {
+    struct rebind {
         typedef aligned_allocator<U, alignment> other;
     };
 
-    pointer address (reference r) const
-    {
+    pointer address(reference r) const {
         return & r;
     }
 
-    const_pointer address (const_reference r) const
-    {
+    const_pointer address(const_reference r) const {
         return & r;
     }
 
-    pointer allocate (size_t n, const void * /* hint */ = 0)
-    {
+    pointer allocate(size_t n, const void * /* hint */ = 0) {
         void * result = nullptr;
         if (posix_memalign(& result, alignment, n * sizeof(T))) {
             throw std::bad_alloc();
@@ -111,23 +104,19 @@ public:
         return static_cast<pointer>(result);
     }
 
-    void deallocate (pointer p, size_type /* count */ )
-    {
+    void deallocate(pointer p, size_type /* count */ ) {
         free(p);
     }
 
-    void construct (pointer p, const T & val)
-    {
-        new (p) T(val);
+    void construct(pointer p, const T & val) {
+        new(p) T(val);
     }
 
-    void destroy (pointer p)
-    {
+    void destroy(pointer p) {
         p->~T();
     }
 
-    size_type max_size () const throw()
-    {
+    size_type max_size() const throw() {
         return std::numeric_limits<size_t>::max() / sizeof(T);
     }
 };
@@ -135,17 +124,15 @@ public:
 template<class T1, class T2>
 inline bool operator== (
         const aligned_allocator<T1> &,
-        const aligned_allocator<T2> &) throw()
-{
+        const aligned_allocator<T2> &) throw() {
     return true;
 }
 
 template<class T1, class T2>
 inline bool operator!= (
         const aligned_allocator<T1> &,
-        const aligned_allocator<T2> &) throw()
-{
+        const aligned_allocator<T2> &) throw() {
     return false;
 }
 
-} // namespace distributions
+}   // namespace distributions
