@@ -27,6 +27,7 @@
 
 #pragma once
 
+#include <vector>
 #include <distributions/common.hpp>
 #include <distributions/special.hpp>
 #include <distributions/random.hpp>
@@ -34,11 +35,8 @@
 #include <distributions/mixins.hpp>
 #include <distributions/mixture.hpp>
 
-namespace distributions
-{
-struct NormalInverseChiSq
-{
-
+namespace distributions {
+struct NormalInverseChiSq {
 typedef NormalInverseChiSq Model;
 typedef float Value;
 struct Group;
@@ -51,15 +49,13 @@ typedef MixtureSlave<Model, MixtureDataScorer, MixtureValueScorer> FastMixture;
 typedef FastMixture Mixture;
 
 
-struct Shared : SharedMixin<Model>
-{
+struct Shared : SharedMixin<Model> {
     float mu;
     float kappa;
     float sigmasq;
     float nu;
 
-    Shared plus_group (const Group & group) const
-    {
+    Shared plus_group(const Group & group) const {
         Shared post;
         float mu_1 = mu - group.mean;
         post.kappa = kappa + group.count;
@@ -73,8 +69,7 @@ struct Shared : SharedMixin<Model>
     }
 
     template<class Message>
-    void protobuf_load (const Message & message)
-    {
+    void protobuf_load(const Message & message) {
         mu = message.mu();
         kappa = message.kappa();
         sigmasq = message.sigmasq();
@@ -82,16 +77,14 @@ struct Shared : SharedMixin<Model>
     }
 
     template<class Message>
-    void protobuf_dump (Message & message) const
-    {
+    void protobuf_dump(Message & message) const {
         message.set_mu(mu);
         message.set_kappa(kappa);
         message.set_sigmasq(sigmasq);
         message.set_nu(nu);
     }
 
-    static Shared EXAMPLE ()
-    {
+    static Shared EXAMPLE() {
         Shared shared;
         shared.mu = 0.0;
         shared.kappa = 1.0;
@@ -102,65 +95,58 @@ struct Shared : SharedMixin<Model>
 };
 
 
-struct Group : GroupMixin<Model>
-{
+struct Group : GroupMixin<Model> {
     int count;
     float mean;
     float count_times_variance;
 
     template<class Message>
-    void protobuf_load (const Message & message)
-    {
+    void protobuf_load(const Message & message) {
         count = message.count();
         mean = message.mean();
         count_times_variance = message.count_times_variance();
     }
 
     template<class Message>
-    void protobuf_dump (Message & message) const
-    {
+    void protobuf_dump(Message & message) const {
         message.set_count(count);
         message.set_mean(mean);
         message.set_count_times_variance(count_times_variance);
     }
 
-    void init (
+    void init(
             const Shared &,
-            rng_t &)
-    {
+            rng_t &) {
         count = 0;
         mean = 0.f;
         count_times_variance = 0.f;
     }
 
-    void add_value (
+    void add_value(
             const Shared &,
             const Value & value,
-            rng_t &)
-    {
+            rng_t &) {
         ++count;
         float delta = value - mean;
         mean += delta / count;
         count_times_variance += delta * (value - mean);
     }
 
-    void add_repeated_value (
+    void add_repeated_value(
             const Shared &,
             const Value & value,
             const int & count,
-            rng_t &)
-    {
+            rng_t &) {
         this->count += count;
         float delta = count * value - mean;
         mean += delta / this->count;
         count_times_variance += delta * (value - mean);
     }
 
-    void remove_value (
+    void remove_value(
             const Shared &,
             const Value & value,
-            rng_t &)
-    {
+            rng_t &) {
         float total = mean * count;
         float delta = value - mean;
         DIST_ASSERT(count > 0, "Can't remove empty group");
@@ -178,14 +164,13 @@ struct Group : GroupMixin<Model>
         }
     }
 
-    void merge (
+    void merge(
             const Shared &,
             const Group & source,
-            rng_t &)
-    {
+            rng_t &) {
         auto total_count = count + source.count;
         float delta = source.mean - mean;
-        float source_part = float(source.count) / total_count;
+        float source_part = static_cast<float>(source.count) / total_count;
         float cross_part = count * source_part;
         count = total_count;
         mean += source_part * delta;
@@ -193,20 +178,18 @@ struct Group : GroupMixin<Model>
             source.count_times_variance + cross_part * sqr(delta);
     }
 
-    float score_value (
+    float score_value(
             const Shared & shared,
             const Value & value,
-            rng_t & rng) const
-    {
+            rng_t & rng) const {
         Scorer scorer;
         scorer.init(shared, * this, rng);
         return scorer.eval(shared, value, rng);
     }
 
-    float score_data (
+    float score_data(
             const Shared & shared,
-            rng_t &) const
-    {
+            rng_t &) const {
         Shared post = shared.plus_group(*this);
         float log_pi = 1.1447298858493991f;
         float score = fast_lgamma(0.5f * post.nu)
@@ -218,51 +201,45 @@ struct Group : GroupMixin<Model>
         return score;
     }
 
-    Value sample_value (
+    Value sample_value(
             const Shared & shared,
-            rng_t & rng) const
-    {
+            rng_t & rng) const {
         Sampler sampler;
         sampler.init(shared, *this, rng);
         return sampler.eval(shared, rng);
     }
 };
 
-struct Sampler
-{
+struct Sampler {
     float mu;
     float sigmasq;
 
-    void init (
+    void init(
             const Shared & shared,
             const Group & group,
-            rng_t & rng)
-    {
+            rng_t & rng) {
         Shared post = shared.plus_group(group);
         sigmasq = post.nu * post.sigmasq / sample_chisq(rng, post.nu);
         mu = sample_normal(rng, post.mu, sigmasq / post.kappa);
     }
 
-    Value eval (
+    Value eval(
             const Shared &,
-            rng_t & rng) const
-    {
+            rng_t & rng) const {
         return sample_normal(rng, mu, sigmasq);
     }
 };
 
-struct Scorer
-{
+struct Scorer {
     float score;
     float log_coeff;
     float precision;
     float mean;
 
-    void init (
+    void init(
             const Shared & shared,
             const Group & group,
-            rng_t &)
-    {
+            rng_t &) {
         Shared post = shared.plus_group(group);
         float lambda = post.kappa / ((post.kappa + 1.f) * post.sigmasq);
         score = fast_lgamma_nu(post.nu)
@@ -272,24 +249,22 @@ struct Scorer
         mean = post.mu;
     }
 
-    float eval (
+    float eval(
             const Shared &,
             const Value & value,
-            rng_t &) const
-    {
+            rng_t &) const {
         return score
              + log_coeff * fast_log(
                  1.f + precision * sqr(value - mean));
     }
 };
 
-struct MixtureDataScorer : MixtureSlaveDataScorerMixin<Model, MixtureDataScorer>
-{
-    float score_data (
+struct MixtureDataScorer
+    : MixtureSlaveDataScorerMixin<Model, MixtureDataScorer> {
+    float score_data(
             const Shared & shared,
             const std::vector<Group> & groups,
-            rng_t &) const
-    {
+            rng_t &) const {
         const float nu_part = fast_lgamma(0.5f * shared.nu);
         const float kappa_part = 0.5f * fast_log(shared.kappa);
         const float sigmasq_part =
@@ -297,7 +272,7 @@ struct MixtureDataScorer : MixtureSlaveDataScorerMixin<Model, MixtureDataScorer>
         const float log_pi = 1.1447298858493991f;
 
         float score = 0;
-        for (const auto & group : groups) {
+        for (auto const & group : groups) {
             if (group.count) {
                 Shared post = shared.plus_group(group);
                 score += fast_lgamma(0.5f * post.nu) - nu_part;
@@ -312,10 +287,8 @@ struct MixtureDataScorer : MixtureSlaveDataScorerMixin<Model, MixtureDataScorer>
     }
 };
 
-struct MixtureValueScorer : MixtureSlaveValueScorerMixin<Model>
-{
-    void resize(const Shared &, size_t size)
-    {
+struct MixtureValueScorer : MixtureSlaveValueScorerMixin<Model> {
+    void resize(const Shared &, size_t size) {
         score_.resize(size);
         log_coeff_.resize(size);
         precision_.resize(size);
@@ -323,8 +296,7 @@ struct MixtureValueScorer : MixtureSlaveValueScorerMixin<Model>
         temp_.resize(size);
     }
 
-    void add_group (const Shared &, rng_t &)
-    {
+    void add_group(const Shared &, rng_t &) {
         score_.packed_add();
         log_coeff_.packed_add();
         precision_.packed_add();
@@ -332,8 +304,7 @@ struct MixtureValueScorer : MixtureSlaveValueScorerMixin<Model>
         temp_.packed_add();
     }
 
-    void remove_group (const Shared &, size_t groupid)
-    {
+    void remove_group(const Shared &, size_t groupid) {
         score_.packed_remove(groupid);
         log_coeff_.packed_remove(groupid);
         precision_.packed_remove(groupid);
@@ -341,12 +312,11 @@ struct MixtureValueScorer : MixtureSlaveValueScorerMixin<Model>
         temp_.packed_remove(groupid);
     }
 
-    void update_group (
+    void update_group(
             const Shared & shared,
             size_t groupid,
             const Group & group,
-            rng_t & rng)
-    {
+            rng_t & rng) {
         Model::Scorer base;
         base.init(shared, group, rng);
 
@@ -356,60 +326,55 @@ struct MixtureValueScorer : MixtureSlaveValueScorerMixin<Model>
         mean_[groupid] = base.mean;
     }
 
-    void add_value (
+    void add_value(
             const Shared & shared,
             size_t groupid,
             const Group & group,
             const Value &,
-            rng_t & rng)
-    {
+            rng_t & rng) {
         update_group(shared, groupid, group, rng);
     }
 
-    void remove_value (
+    void remove_value(
             const Shared & shared,
             size_t groupid,
             const Group & group,
             const Value &,
-            rng_t & rng)
-    {
+            rng_t & rng) {
         update_group(shared, groupid, group, rng);
     }
 
-    void update_all (
+    void update_all(
             const Shared & shared,
             const std::vector<Group> & groups,
-            rng_t & rng)
-    {
+            rng_t & rng) {
         const size_t group_count = groups.size();
         for (size_t groupid = 0; groupid < group_count; ++groupid) {
             update_group(shared, groupid, groups[groupid], rng);
         }
     }
 
-    float score_value_group (
+    float score_value_group(
             const Shared &,
             const std::vector<Group> &,
             size_t groupid,
             const Value & value,
-            rng_t &) const
-    {
+            rng_t &) const {
         float temp = 1.f + precision_[groupid] * sqr(value - mean_[groupid]);
         return score_[groupid] + log_coeff_[groupid] * fast_log(temp);
     }
 
     // not thread safe
-    void score_value (
+    void score_value(
             const Shared &,
             const std::vector<Group> &,
             const Value & value,
             AlignedFloats scores_accum,
             rng_t &) const;
 
-    void validate (
+    void validate(
             const Shared &,
-            const std::vector<Group> & groups) const
-    {
+            const std::vector<Group> & groups) const {
         DIST_ASSERT_EQ(score_.size(), groups.size());
         DIST_ASSERT_EQ(log_coeff_.size(), groups.size());
         DIST_ASSERT_EQ(precision_.size(), groups.size());
@@ -417,14 +382,12 @@ struct MixtureValueScorer : MixtureSlaveValueScorerMixin<Model>
         DIST_ASSERT_EQ(temp_.size(), groups.size());
     }
 
-private:
-
+  private:
     VectorFloat score_;
     VectorFloat log_coeff_;
     VectorFloat precision_;
     VectorFloat mean_;
     mutable VectorFloat temp_;
 };
-
-}; // struct NormalInverseChiSq
-} // namespace distributions
+};  // struct NormalInverseChiSq
+}   // namespace distributions
