@@ -29,16 +29,14 @@
 #include <distributions/clustering.hpp>
 #include <distributions/special.hpp>
 
-namespace distributions
-{
+namespace distributions {
 
-//----------------------------------------------------------------------------
+// --------------------------------------------------------------------------
 // Assignments
 
 template<class count_t>
-std::vector<count_t> Clustering<count_t>::count_assignments (
-        const Assignments & assignments)
-{
+std::vector<count_t> Clustering<count_t>::count_assignments(
+        const Assignments & assignments) {
     // Count group sizes in an assignment vector with the following properties:
     // 0 is the first group
     // there are no empty groups
@@ -65,14 +63,13 @@ std::vector<count_t> Clustering<count_t>::count_assignments (
 }
 
 
-//----------------------------------------------------------------------------
+// --------------------------------------------------------------------------
 // Pitman-Yor Model
 
 template<class count_t>
-std::vector<count_t> Clustering<count_t>::PitmanYor::sample_assignments (
+std::vector<count_t> Clustering<count_t>::PitmanYor::sample_assignments(
         count_t size,
-        rng_t & rng) const
-{
+        rng_t & rng) const {
     // Note that we can ignore the constant shift of -log(size + alpha) in
     //
     //   float py.score_add_value(
@@ -88,7 +85,9 @@ std::vector<count_t> Clustering<count_t>::PitmanYor::sample_assignments (
     //
     // which then permits caching of each table's score.
 
-    DIST_ASSERT(float(size) + 1.f > float(size), "underflow expected");
+    DIST_ASSERT(
+        static_cast<float>(size) + 1.f > static_cast<float>(size),
+        "underflow expected");
 
     std::vector<count_t> assignments(size);
     std::vector<float> likelihoods;
@@ -117,7 +116,6 @@ std::vector<count_t> Clustering<count_t>::PitmanYor::sample_assignments (
 
     // add all remaining entries
     for (count_t i = 1; DIST_LIKELY(i < size); ++i) {
-
         // This is cool - for fixed alpha, d, the likelihood will roughly
         // exponentially decay along the likelihood vector.  And in sampling
         // we linearly scan from the front, so we only need to examine an
@@ -128,7 +126,6 @@ std::vector<count_t> Clustering<count_t>::PitmanYor::sample_assignments (
         assignments[i] = assign;
 
         if (DIST_UNLIKELY(assign == table_count)) {
-
             // new table
             table_count += 1;
             const float py_likelihood_empty = alpha + d * table_count;
@@ -136,7 +133,6 @@ std::vector<count_t> Clustering<count_t>::PitmanYor::sample_assignments (
             likelihoods[assign] = py_likelihood_new;
 
         } else {
-
             // existing table
             likelihoods[assign] += 1.0f;
         }
@@ -145,20 +141,17 @@ std::vector<count_t> Clustering<count_t>::PitmanYor::sample_assignments (
     return assignments;
 }
 
-inline float fast_log_ratio (float numer, float denom)
-{
+inline float fast_log_ratio(float numer, float denom) {
     return fast_log(numer / denom);
 }
 
-inline float fast_lgamma_ratio (float start, size_t count)
-{
+inline float fast_lgamma_ratio(float start, size_t count) {
     return fast_lgamma(start + count) - fast_lgamma(start);
 }
 
 template<class count_t>
-float Clustering<count_t>::PitmanYor::score_counts (
-        const std::vector<count_t> & counts) const
-{
+float Clustering<count_t>::PitmanYor::score_counts(
+        const std::vector<count_t> & counts) const {
     double score = 0.0;
     size_t sample_size = 0;
     size_t nonempty_group_count = 0;
@@ -166,19 +159,16 @@ float Clustering<count_t>::PitmanYor::score_counts (
     for (size_t count : counts) {
         if (count) {
             if (count == 1) {
-
                 score += fast_log_ratio(
                     alpha + d * nonempty_group_count,
                     alpha + sample_size);
 
             } else if (count == 2) {
-
                 score += fast_log_ratio(
                     (alpha + d * nonempty_group_count) * (1 - d),
                     (alpha + sample_size) * (alpha + sample_size + 1));
 
             } else {
-
                 score += fast_log(alpha + d * nonempty_group_count);
                 score += fast_lgamma_ratio(1 - d, count - 1);
                 score -= fast_lgamma_ratio(alpha + sample_size, count);
@@ -192,12 +182,11 @@ float Clustering<count_t>::PitmanYor::score_counts (
     return score;
 }
 
-//----------------------------------------------------------------------------
+// --------------------------------------------------------------------------
 // Low-Entropy Model
 
 // this code was generated by derivations/clustering.py
-static const float log_partition_function_table[48] =
-{
+static const float log_partition_function_table[48] = {
     0.00000000, 0.00000000, 1.60943791, 3.68887945, 6.07993320,
     8.70549682, 11.51947398, 14.49108422, 17.59827611, 20.82445752,
     24.15668300, 27.58456586, 31.09958507, 34.69462231, 38.36364086,
@@ -212,10 +201,9 @@ static const float log_partition_function_table[48] =
 
 // this code was generated by derivations/clustering.py
 template<class count_t>
-float Clustering<count_t>::LowEntropy::log_partition_function (
-        count_t sample_size) const
-{
-    // TODO incorporate dataset_size for higher accuracy
+float Clustering<count_t>::LowEntropy::log_partition_function(
+        count_t sample_size) const {
+    // TODO(fobermeyer) incorporate dataset_size for higher accuracy
     count_t n = sample_size;
     if (n < 48) {
         return log_partition_function_table[n];
@@ -230,18 +218,16 @@ float Clustering<count_t>::LowEntropy::log_partition_function (
 // see `python derivations/clustering.py dataprob`
 // see `python derivations/clustering.py approximations`
 template<class count_t>
-inline float Clustering<count_t>::LowEntropy::_approximate_dataprob_correction (
-        count_t sample_size) const
-{
+inline float Clustering<count_t>::LowEntropy::_approximate_dataprob_correction(
+        count_t sample_size) const {
     float n = fast_log(sample_size);
     float N = fast_log(dataset_size);
     return 0.061f * n * (n - N) * powf(n + N, 0.75f);
 }
 
 template<class count_t>
-float Clustering<count_t>::LowEntropy::score_counts (
-        const std::vector<count_t> & counts) const
-{
+float Clustering<count_t>::LowEntropy::score_counts(
+        const std::vector<count_t> & counts) const {
     float score = 0.0;
     count_t sample_size = 0;
     for (count_t count : counts) {
@@ -262,10 +248,9 @@ float Clustering<count_t>::LowEntropy::score_counts (
 }
 
 template<class count_t>
-std::vector<count_t> Clustering<count_t>::LowEntropy::sample_assignments (
+std::vector<count_t> Clustering<count_t>::LowEntropy::sample_assignments(
         count_t sample_size,
-        rng_t & rng) const
-{
+        rng_t & rng) const {
     DIST_ASSERT_LE(sample_size, dataset_size);
 
     std::vector<count_t> assignments(sample_size);
@@ -277,7 +262,6 @@ std::vector<count_t> Clustering<count_t>::LowEntropy::sample_assignments (
     count_t size = 0;
 
     for (count_t & assign : assignments) {
-
         float likelihood_empty = fast_exp(score_add_value(0, bogus, size));
         if (DIST_UNLIKELY(counts.empty()) or counts.back()) {
             counts.push_back(0);
@@ -299,12 +283,14 @@ std::vector<count_t> Clustering<count_t>::LowEntropy::sample_assignments (
 }
 
 
-//----------------------------------------------------------------------------
+// --------------------------------------------------------------------------
 // Explicit template instantiation
 
 template struct Clustering<int32_t>;
-//template struct Clustering<int64_t>;
-//template struct Clustering<uint32_t>;
-//template struct Clustering<uint64_t>;
+#if 0
+template struct Clustering<int64_t>;
+template struct Clustering<uint32_t>;
+template struct Clustering<uint64_t>;
+#endif
 
-} // namespace distributions
+}   // namespace distributions
